==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE51S.sql <==
/****************************************************************************/
/* GE51 ( 帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2016/10/27 10:57:15                                            */
/****************************************************************************/

CREATE TABLE GE51 (
   SYSTEM_ID    varchar (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , YKNO         INTEGER                 DEFAULT 0   NOT NULL            /*  20 要求NO   */
 , EDNO         INTEGER                 DEFAULT 0   NOT NULL            /*  30 枝番     */
 , KBTEXT       varchar (    1 )                    NOT NULL            /*  40 ﾃｷｽﾄ区分 */
 , TEXT_DATA    varchar ( 4000 )                                        /*  50 ﾃｷｽﾄ     */
 , FGJ          varchar (    1 )        DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar (   14 )                                        /* 820 登録日時 */
 , PGSET        varchar (   10 )                                        /* 830 作成PG   */
 , PGPSET       varchar (   10 )                                        /* 840 作成親PG */
 , USRSET       varchar (   10 )                                        /* 850 作成社員 */
 , DYUPD        varchar (   14 )                                        /* 860 更新日時 */
 , PGUPD        varchar (   10 )                                        /* 870 更新PG   */
 , PGPUPD       varchar (   10 )                                        /* 880 更新親PG */
 , USRUPD       varchar (   10 )                                        /* 890 更新者   */
);

==> openGion6.9.7.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE51S.sql <==
/****************************************************************************/
/* GE51 ( 帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GE51 (
   SYSTEM_ID    varchar (   10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , YKNO         INTEGER                 DEFAULT 0   NOT NULL            /*  20 要求NO   */
 , EDNO         INTEGER                 DEFAULT 0   NOT NULL            /*  30 枝番     */
 , KBTEXT       varchar (    1 )                    NOT NULL            /*  40 ﾃｷｽﾄ区分 */
 , TEXT_DATA    varchar ( 4000 )                                        /*  50 ﾃｷｽﾄ     */
 , FGJ          varchar (    1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar (   14 )                                        /* 820 登録日時 */
 , PGSET        varchar (   10 )                                        /* 830 作成PG   */
 , PGPSET       varchar (   10 )                                        /* 840 作成親PG */
 , USRSET       varchar (   10 )                                        /* 850 作成社員 */
 , DYUPD        varchar (   14 )                                        /* 860 更新日時 */
 , PGUPD        varchar (   10 )                                        /* 870 更新PG   */
 , PGPUPD       varchar (   10 )                                        /* 880 更新親PG */
 , USRUPD       varchar (   10 )                                        /* 890 更新者   */
);
